@@ -5,23 +5,18 @@
 
 # this is executed before each test function -- but somehow does not work
 .setUp <- function() {
-    #file <- system.file( "examples", "addressbook.pb", package = "RProtoBuf" )
-    #book <- read( tutorial.AddressBook, file )
+    file <- system.file( "examples", "addressbook.pb", package = "RProtoBuf" )
+    book <- read( tutorial.AddressBook, file )
+    assign("book", book, globalenv())
 }
 
 test.size <- function() {
-    # re-set file and book
-    file <- system.file( "examples", "addressbook.pb", package = "RProtoBuf" )
-    book <- read( tutorial.AddressBook, file )
     checkEquals(book$size("person"),        2,   msg="Number of persons")
     checkEquals(bytesize(book),             125, msg="Bytes in book")
     checkEquals(bytesize(book$person[[1]]), 60,  msg="Bytes of first person message")
 }
 
 test.personOne <- function() {
-    # re-set file and book
-    file <- system.file( "examples", "addressbook.pb", package = "RProtoBuf" )
-    book <- read( tutorial.AddressBook, file )
     checkEquals(book$person[[1]]$name,              "Romain Francois",   msg="First person name")
     checkEquals(book$person[[2]]$name,              "Dirk Eddelbuettel", msg="First person name")
     checkEquals(book$person[[1]]$id,                1,   		 msg="First person id")
